@@ -1,4 +1,4 @@
-# $Id: b258fb24663a92a9a4d6e1ddf9a55c8af897cfde $
+# $Id: 50757e338101e0c27be5d32d45c7e74993964ba7 $
 #
 # This file is sourced AFTER defaults/config.sh; generic options should be set there.
 # Arch-specific options that normally shouldn't be changed.
@@ -8,11 +8,10 @@ KERNEL_MAKE_DIRECTIVE_2=""
 KERNEL_BINARY="./vmlinux"
 
 # Initrd/Initramfs Options
-NOINITRDMODULES="yes"
-BUSYBOX=1
-DMRAID=0
-DISKLABEL=0
+RAMDISKMODULES="no"
+BUSYBOX="yes"
+DMRAID="no"
 
 # genkernel on mips is only used for LiveCDs && netboots.  Catalyst
 # will know where to get the kernels at.
-CMD_INSTALL=0
+INSTALL="no"
